@@ -59,6 +59,7 @@
 #'                                         k_seq = c(0.5, 0.75, 1))
 #' mod_list <- fof_pc_real_time(mfdobj_y_list, mfdobj_x_list)
 #'
+#' @author C. Capezza, F. Centofanti
 fof_pc_real_time <- function(mfdobj_y_list,
                              mfdobj_x_list,
                              tot_variance_explained_x = 0.95,
@@ -91,23 +92,23 @@ fof_pc_real_time <- function(mfdobj_y_list,
     mod_list <- lapply(seq_along(mfdobj_y_list), single_k)
   } else {
     if (.Platform$OS.type == "unix") {
-      mod_list <- mclapply(seq_along(mfdobj_y_list),
-                           single_k,
-                           mc.cores = ncores)
+      mod_list <- parallel::mclapply(seq_along(mfdobj_y_list),
+                                     single_k,
+                                     mc.cores = ncores)
     } else {
-      cl <- makeCluster(ncores)
-      clusterExport(cl,
-                    c("mfdobj_y_list",
-                      "mfdobj_x_list",
-                      "tot_variance_explained_x",
-                      "tot_variance_explained_y",
-                      "tot_variance_explained_res",
-                      "components_x",
-                      "components_y",
-                      "type_residuals"),
-                    envir = environment())
-      mod_list <- parLapply(cl, seq_along(mfdobj_y_list), single_k)
-      stopCluster(cl)
+      cl <- parallel::makeCluster(ncores)
+      parallel::clusterExport(cl,
+                              c("mfdobj_y_list",
+                                "mfdobj_x_list",
+                                "tot_variance_explained_x",
+                                "tot_variance_explained_y",
+                                "tot_variance_explained_res",
+                                "components_x",
+                                "components_y",
+                                "type_residuals"),
+                              envir = environment())
+      mod_list <- parallel::parLapply(cl, seq_along(mfdobj_y_list), single_k)
+      parallel::stopCluster(cl)
     }
   }
 
